@@ -37,6 +37,7 @@ type App struct {
 	DisableForceUpdate         bool
 
 	Logger      *zap.SugaredLogger
+	Kubeconfig  string
 	Env         string
 	Namespace   string
 	Chart       string
@@ -81,6 +82,7 @@ func New(conf ConfigProvider) *App {
 		StripArgsValuesOnExitError: conf.StripArgsValuesOnExitError(),
 		DisableForceUpdate:         conf.DisableForceUpdate(),
 		Logger:                     conf.Logger(),
+		Kubeconfig:                 conf.Kubeconfig(),
 		Env:                        conf.Env(),
 		Namespace:                  conf.Namespace(),
 		Chart:                      conf.Chart(),
@@ -789,12 +791,13 @@ func (a *App) getHelm(st *state.HelmState) helmexec.Interface {
 	}
 
 	bin := st.DefaultHelmBinary
+	kubeconfig := a.Kubeconfig
 	kubectx := st.HelmDefaults.KubeContext
 
 	key := createHelmKey(bin, kubectx)
 
 	if _, ok := a.helms[key]; !ok {
-		a.helms[key] = helmexec.New(bin, helmexec.HelmExecOptions{EnableLiveOutput: a.EnableLiveOutput, DisableForceUpdate: a.DisableForceUpdate}, a.Logger, kubectx, &helmexec.ShellRunner{
+		a.helms[key] = helmexec.New(bin, helmexec.HelmExecOptions{EnableLiveOutput: a.EnableLiveOutput, DisableForceUpdate: a.DisableForceUpdate}, a.Logger, kubeconfig, kubectx, &helmexec.ShellRunner{
 			Logger:                     a.Logger,
 			Ctx:                        a.ctx,
 			StripArgsValuesOnExitError: a.StripArgsValuesOnExitError,
@@ -1080,7 +1083,11 @@ func (a *App) visitStatesWithSelectorsAndRemoteSupport(fileOrDir string, converg
 
 	// pre-overrides HelmState
 	fHelmStatsWithOverrides := func(st *state.HelmState) (bool, []error) {
-		st.Releases = st.GetReleasesWithOverrides()
+		var err error
+		st.Releases, err = st.GetReleasesWithOverrides()
+		if err != nil {
+			return false, []error{err}
+		}
 		return f(st)
 	}
 
@@ -1108,7 +1115,7 @@ func processFilteredReleases(st *state.HelmState, converge func(st *state.HelmSt
 
 func checkDuplicates(releases []state.ReleaseSpec) error {
 	type Key struct {
-		TillerNamespace, Name, KubeContext string
+		Namespace, Name, KubeContext string
 	}
 
 	releaseNameCounts := map[Key]int{}
@@ -1120,8 +1127,8 @@ func checkDuplicates(releases []state.ReleaseSpec) error {
 		if c > 1 {
 			var msg string
 
-			if name.TillerNamespace != "" {
-				msg += fmt.Sprintf(" in namespace %q", name.TillerNamespace)
+			if name.Namespace != "" {
+				msg += fmt.Sprintf(" in namespace %q", name.Namespace)
 			}
 
 			if name.KubeContext != "" {
@@ -1476,6 +1483,7 @@ Do you really want to apply?
 					ResetValues:      c.ResetValues(),
 					PostRenderer:     c.PostRenderer(),
 					PostRendererArgs: c.PostRendererArgs(),
+					SyncArgs:         c.SyncArgs(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1674,10 +1682,9 @@ func (a *App) status(r *Run, c StatusesConfigProvider) (bool, []error) {
 
 	var toStatus []state.ReleaseSpec
 	for _, r := range selectedReleases {
-		if !r.Desired() {
-			continue
+		if r.Desired() {
+			toStatus = append(toStatus, r)
 		}
-		toStatus = append(toStatus, r)
 	}
 
 	var errs []error
@@ -1757,7 +1764,7 @@ func (a *App) sync(r *Run, c SyncConfigProvider) (bool, []error) {
 	for _, r := range toSyncWithNeeds {
 		release := r
 		if _, deleted := releasesToDelete[state.ReleaseToID(&release)]; !deleted {
-			if release.Installed == nil || *release.Installed {
+			if r.Desired() {
 				toUpdate = append(toUpdate, release)
 			}
 			// TODO Emit error when the user opted to fail when the needed release is disabled,
@@ -1869,6 +1876,7 @@ Do you really want to sync?
 					ResetValues:      c.ResetValues(),
 					PostRenderer:     c.PostRenderer(),
 					PostRendererArgs: c.PostRendererArgs(),
+					SyncArgs:         c.SyncArgs(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
 			}))
@@ -1950,7 +1958,7 @@ func (a *App) withNeeds(r *Run, c DAGConfig, includeDisabled bool, f func(*state
 	for _, r := range selectedReleasesWithNeeds {
 		release := r
 		id := state.ReleaseToID(&release)
-		if release.Installed != nil && !*release.Installed {
+		if !release.Desired() {
 			releasesToUninstall[id] = release
 		} else {
 			toRender = append(toRender, release)
@@ -2035,10 +2043,9 @@ func (a *App) writeValues(r *Run, c WriteValuesConfigProvider) (bool, []error) {
 	for _, r := range toRender {
 		release := r
 		id := state.ReleaseToID(&release)
-		if release.Installed != nil && !*release.Installed {
-			continue
+		if release.Desired() {
+			releasesToWrite[id] = release
 		}
-		releasesToWrite[id] = release
 	}
 
 	var errs []error
