@@ -18,6 +18,7 @@ type ConfigProvider interface {
 	Selectors() []string
 	StateValuesSet() map[string]any
 	StateValuesFiles() []string
+	Kubeconfig() string
 	Env() string
 
 	loggingConfig
@@ -83,6 +84,7 @@ type ApplyConfigProvider interface {
 	SkipDiffOnInstall() bool
 
 	DiffArgs() string
+	SyncArgs() string
 
 	DAGConfig
 
@@ -104,6 +106,7 @@ type SyncConfigProvider interface {
 	SkipDeps() bool
 	Wait() bool
 	WaitForJobs() bool
+	SyncArgs() string
 
 	Validate() bool
 
