@@ -18,8 +18,8 @@ import (
 
 const (
 	HelmRequiredVersion           = "v3.13.3"
-	HelmRecommendedVersion        = "v3.14.1"
-	HelmDiffRecommendedVersion    = "v3.9.4"
+	HelmRecommendedVersion        = "v3.14.3"
+	HelmDiffRecommendedVersion    = "v3.9.5"
 	HelmSecretsRecommendedVersion = "v4.1.1"
 	HelmGitRecommendedVersion     = "v0.12.0"
 	HelmS3RecommendedVersion      = "v0.14.0"
@@ -163,7 +163,7 @@ func (h *HelmfileInit) WhetherContinue(ask string) error {
 
 func (h *HelmfileInit) CheckHelmPlugins() error {
 	settings := cli.New()
-	helm := helmexec.New(h.helmBinary, helmexec.HelmExecOptions{}, h.logger, "", h.runner)
+	helm := helmexec.New(h.helmBinary, helmexec.HelmExecOptions{}, h.logger, "", "", h.runner)
 	for _, p := range helmPlugins {
 		pluginVersion, err := helmexec.GetPluginVersion(p.name, settings.PluginsDirectory)
 		if err != nil {
